@@ -1,7 +1,6 @@
 package DTL::Fast::Filter::Getdigit;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Filter';
-use Carp;
 
 $DTL::Fast::FILTER_HANDLERS{'get_digit'} = __PACKAGE__;
 
@@ -9,7 +8,7 @@ $DTL::Fast::FILTER_HANDLERS{'get_digit'} = __PACKAGE__;
 sub parse_parameters
 {
     my $self = shift;
-    carp "No digit number specified"
+    die "No digit number specified"
         if not scalar @{$self->{'parameter'}};
     $self->{'digit'} = $self->{'parameter'}->[0];
     return $self;
