@@ -4,19 +4,12 @@ use parent 'DTL::Fast::Tag::Simple';
 
 $DTL::Fast::TAG_HANDLERS{'extends'} = __PACKAGE__;
 
+use DTL::Fast::Template;
+
 #@Override
 sub parse_parameters
 {
     my $self = shift;
-
-    die sprintf("Structure error. Top-level object for %s must be a DTL::Fast::Template, not %s (%s)"
-        , __PACKAGE__
-        , $self->{'_template'} // 'undef'
-        , ref $self->{'_template'} || 'SCALAR' 
-    ) if not $self->{'_template'}
-        or not ref $self->{'_template'}
-        or not $self->{'_template'}->isa('DTL::Fast::Template')
-    ;
     
     my $parent_template = '';
     die "Parent template was not specified"
@@ -24,11 +17,11 @@ sub parse_parameters
             or not ($parent_template = DTL::Fast::Variable->new($self->{'parameter'})->render());
             
     die sprintf("Multiple extends specified in the template:\n\%s\n\%s\n"
-        , $self->{'_template'}->{'extends'}
+        , $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'}
         , $parent_template
-    ) if $self->{'_template'}->{'extends'};
+    ) if $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'};
             
-    $self->{'_template'}->{'extends'} = $parent_template;
+    $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'} = $parent_template;
     
     return;
 }
